@@ -250,7 +250,10 @@
 /**
  * gtkosx_application_get:
  *
- * Returns: (transfer none) the singleton application object.
+ * Get the singleton NSApplication object.
+ *
+ * Returns: (transfer none): the singleton application object.
+ *
  */
 GtkosxApplication *
 gtkosx_application_get (void)
@@ -288,16 +291,3 @@ gtkosx_application_set_use_quartz_accelerators (GtkosxApplication *self,
 {
   self->priv->use_quartz_accelerators = use_quartz_accelerators;
 }
-
-/*
- * gtk_type_osxapplication_attention_type_get_type:
- *
- * A public enum used to set the parameter for attention
- * requests. Exists soley to satisfy the PyGObject codegen system.
- */
-GType
-gtkosx_type_application_attention_type_get_type (void)
-{
-  //Bogus GType, but there's no good reason to register this; it's only an enum
-  return GTKOSX_TYPE_APPLICATION;
-}
